====
Home
====

``rst-package-refs`` is referencing support library for Sphinx users.

Base concept
============

This provides these features:

* Support functions kit about creating custom roles to refer package registry for reStructuredText and Sphinx.
* Custom roles to refer major package registry (`PyPI <https://pypi.org>`_, `npm <https://www.npmjs.com/>`_ and more ...).

You can use this by :doc:`easy operation <./usage>` in Sphinx.

.. code:: rst

   :pypi:`rst-package-refs` provides custom roles to refer for packages of PyPI.

This rendered it on HTML.

  :pypi:`rst-package-refs` provides custom roles to refer for packages of PyPI.

Contents
========

.. toctree::
   :maxdepth: 1

   usage
   changelogs
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
